import React, { useState, useEffect } from 'react';
import styled from 'styled-components';
import Grid from '@material-ui/core/Grid';
import SearchInput from './SearchInput.js';
import ResourceCard from './ResourceCard.js';
import SmallFooter from './SmallFooter.js';
import CircularProgress from '@material-ui/core/CircularProgress';
import {getRequest} from '../HelperFunctions/getAxiosConfig'

export default function DrawerContent(props) {
	const [resources, setResources] = useState([]);
	// eslint-disable-next-line
	const [isLoading, setIsLoading] = useState(false); 

    function handleSuccess(data) {
        setResources(data)
    }
	const search = (query) => {
        const url = `/search?
			page=0&results_per_page=5&query=${query}&search_class=LearningObject`

        getRequest(url, handleSuccess, (error) => {console.log(error)})
	}

	useEffect(() => {
		search(props.tag);
		}, [props.tag]);

	useEffect(() => {
		console.log(resources);
	}, [resources]);

	return(
		<Wrapper container
			direction="row"
			justify="center"
			alignItems="flex-start"
		>
			<Grid item xs={11}>
				<SearchInput stdin={props.tag} search={search}/>
			</Grid>
			<Grid item xs={11}>
				<Description>
					Recursos Relacionados na Plataforma MEC:
				</Description>
			</Grid>

			{
				isLoading ? <CircularProgress style={{color : 'white'}}/>
				:
				resources.map((r, index) => {
				return(
					<Grid item xs={11} key={index}>
						<ResourceCard
							id={r.id}
							name={r.name}
							likes={r.likes_count}
							thumb={r.thumbnail}
						/>
					</Grid>
				);}
			)}
			<Grid item xs={12}>
				<SmallFooter />
			</Grid>
		</Wrapper>
		);
}

const Wrapper=styled(Grid)`
	min-width: 400px;
	max-width: 400px;
	background-color: #666;
	height: 100%;
	overflow-x: scroll !important;
`
const Description=styled.p`
	color: white;
	margin-left: 20px !important;
	margin-right: 20px !important;
`
